@@ -3,19 +3,20 @@ from typing import Any
 from fastapi.templating import Jinja2Templates
 
 from .requests import Request
+from .tags import Tag
 
 
-class Jinja2Renderer:
-    """Template renderer to make Jinja2 easier in Air.
+class JinjaRenderer:
+    """Template renderer to make Jinja easier in Air.
 
     Args:
         directory: Template directory
 
     Example:
         # Instantiate the render callable
-        jinja = TemplateRenderer('templates')
+        jinja = JinjaRenderer('templates')
 
-        # Use for returning Jinja2 from views
+        # Use for returning Jinja from views
         @app.get('/')
         async def home(request: Request):
             return jinja(
@@ -43,11 +44,18 @@ class Jinja2Renderer:
         context: dict[Any, Any] | None = None,
         **kwargs,
     ):
-        """Render template with request and context"""
+        """Render template with request and context. If an Air Tag
+        is found in the context, try to render it.
+        """
         if context is None:
             context = {}
         if kwargs:
             context = context | kwargs
+
+        # Attempt to render any Tags in the contect
+        for k, v in context.items():
+            if isinstance(v, Tag) and hasattr(v, "render"):
+                context[k] = v.render()
         return self.templates.TemplateResponse(
             request=request, name=name, context=context
         )
